# simple-distributions-build-2020-hk package

This package contains general, gaussian and binomial distribution. They have common properties like mean and
standard deviation to be called. Each class has its own method for the specific type of distribution.

# Files
Binomialdistribution.py - for Binomial distribution calculation
Gaussiandistribution.py - for Gaussian distribution calculation
Generaldistribution.py - for General distribution calculation

# Installation
Python Version >= 3